{
    package GCLang::IT;
    
    use utf8;
###################################################
#
#  Copyright 2005 Tian
#
#  This file is part of GCfilms.
#
#  GCfilms is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCfilms is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCfilms; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################

    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (

        'LangName' => 'Italiano',
        
        'Separator' => ': ',
        
        'Warning' => '<b>Warning</b>:
        
Information downloaded from Internet sites (thanks to 
search plugins) are only for <b>personal use</b>

Any re-distribution is forbidden whithout <b>explicit
web sites authorisation</b>.

To know which is the web site owning information, you
can use <b>button below film details</b>.',
        
        'AllMoviesFiltered' => 'No movie matches your filtering criteria',

        'InstallDirInfo' => 'Installazione dentro ',
        'InstallMandatory' => 'Componenti obbligatori',
        'InstallOptional' => 'Componenti Facoltativi',
        'InstallErrorMissing' => 'Errore : I seguenti componenti devono essere installati: ',
        'InstallPrompt' => 'Indice per installazione [/usr/local]: ',
        'InstallEnd' => 'Estremità dell\'installazione',
        'InstallNoError' => 'Nessun errore',
        'InstallLaunch' => 'Per usare questa applicazione, si può lanciare ',
        'InstallDirectory' => 'Indice basso',
        'InstallTitle' => 'Installazione di GCfilms',
        'InstallDependencies' => 'Dipendenze',
        'InstallPath' => 'Path',
        'InstallOptions' => 'Options',
        'InstallSelectDirectory' => 'Selezioni l\'indice basso per l\'installazione',
        'InstallWithClean' => 'Rimuovi files trovati nella directory di installazione',
       	'InstallWithMenu' => 'Add GCfilms to Applications menu',
       	'InstallNoPermission' => 'Error: You don\'t have permission to write in the selected directory',
        'InstallMissingMandatory' => 'Mandatory dependencies are missing. You won\'t be able to install GCfilms until they have been added to your system.',
        'InstallMissingOptional' => 'Some optional dependencies are missing. There are listed under. GCfilms may be installed but some features won\'t be available.',
        'InstallMissingNone' => 'There are no missing dependency. You may continue and install GCfilms.',
        'InstallOK' => 'OK',
        'InstallMissing' => 'Missing',
        'InstallMissingFor' => 'Missing for',
        
        'SplashInit' => 'Inizio',
        'SplashLoad' => 'Caricamento films',
        'SplashDone' => 'Pronto',

        'RemoveConfirm' => 'Desideri rimuovere questo film?',
        'NewMovie' => 'Nuovo film',
        'NewMovieTooltip' => 'Aggiungi un nuovo film',
        'NoMovieFound' => 'Nessun film è stato trovato. Desideri effettuare una ricerca su un altro percorso?',
        'OpenList' => 'Scegli la lista film',
        'SaveList' => 'Scegli dove salvare la lista',
        'SaveListTooltip' => 'Salva la lista corrente',
        'SaveCurrentList' => 'In primo luogo specifica dove salvare la lista corrente',
        'Movies' => 'Films',
        'PreferencesTooltip' => 'Imposta preferenze',
        'ViewTooltip' => 'Cambia il tipo di liste',
        'PlayTooltip' => 'Play video associated to the movie',

        'StatusSearch' => 'Ricerca in progresso...',
        'StatusGetInfo' => 'Ottenere le informazioni...',
        'StatusGetImage' => 'Ottenere immagine...',
                
        'SaveError' => 'Non può conservare la lista di film. Controlli prego i diritti di accesso e lo spazio libero del disco',
        'OpenError' => 'Non può aprire la lista di films. Controlli prego i diritti di accesso.',
        'ImageError' => 'L\'indice selezionato per conservare le immagini non è corretto.  Selezioni prego altro.',
        'OptionsCreationError'=> 'Non può generare la lista di opzioni: ',
        'OptionsOpenError'=> 'Non può aprire la lista di opzioni: ',
        'OptionsSaveError'=> 'Non può conservare la lista di opzioni: ',

        'RandomTooltip' => 'Cosa vedo questa sera?',
        'RandomError'=> 'Tu non hai film non visti',
        'RandomEnd'=> 'Non ci sono più films',
        'RandomNextTip'=> 'Prossimo suggerimento',
        'RandomOkTip'=> 'Accetto questo film',
        
        'AboutTitle' => 'Circa GCfilms',
        'AboutDesc' => 'Catalogo di film Gtk2',
        'AboutVersion' => 'Versione',
	'AboutTeam' => 'Team',
        'AboutWho' => 'Tian : Gestione di progetti, Programmazione
MeV : Programmazione
Christophe Z : Programmazione
Adolfo González : Programmazione

Jason Day : Contribuzione
Gabriel Meier : Contribuzione

Dab : Contribuzione
rootII : Contribuzione
VFRMania : Contribuzione',
        'AboutLicense' => 'Distribuito sotto i termini dello GNU GPL
Logos Copyright le Spektre
http://le-spektre.org',
        'AboutTranslation' => 'Traduzione italiana da Ernic',
        'AboutDesign' => 'Logo and webdesign by le Spektre',

        'ToolbarRandom' => 'Stasera',

        'ResultsTitle' => 'Seleziona un film',
        'ResultsMovieTitle' => 'Titolo',
        'ResultsMovieYear' => 'Anno',
        'ResultsMovieDirector' => 'Regista',
        'ResultsMovieActors' => 'Cast',
        'ResultsNextTip' => 'Cerca nel prossimo sito',
        
        'OptionsTitle' => 'Preferenze',
        'OptionsBrowser' => 'Web browser',
        'OptionsPlayer' => 'Video player',
        'OptionsImages' => 'Indice di immagini',
        'OptionsUseRelativePaths' => 'Use relative paths for images',
        'OptionsOrder' => 'Layout',
        'OptionsStatus' => 'Visualizza la barra di stato in fondo alla finestra',
        'OptionsUrlPicture' => 'Visualizza il logo del sito sul pulsante usato per aprire la pagina delle ricerche',
        'OptionsWarning' => 'Avvertimento:  Le opzioni cambiate in questo pannello avranno effetto dopo il riavvio dell\' applicazione',
        'OptionsTabs' => 'Etichette',
        'OptionsAllInOne' => 'All In One',
        'OptionsCompact' => 'Compact',
        'OptionsReadOnly' => 'Read Only',
        'OptionsWebSite' => 'GCfilms Website',
        'OptionsRemoveConfirm' => 'Chiedi conferma prima di rimuovere un film dalla lista',
        'OptionsAutoSave' => 'Salva automaticamente la lista dei film',
        'OptionsSplash' => 'Mostra splashscreen',
        'OptionsImagesTitle' => 'Seleziona un indice',
        'OptionsBrowserTitle' => 'Seleziona il programma per essere usato',
		'OptionsPlugins' => 'Siti da usare per le informazioni dei films',
		'OptionsAskPlugins' => 'Chiedi (Tutti i siti)',
		'OptionsPluginsMulti' => 'Molti siti',
		'OptionsPluginsMultiAsk' => 'Chiedi (Molti siti)',
		'OptionsPluginsList' => 'Configura la lista',
        'OptionsAskImport' => 'Seleziona i campi da importare',
		'OptionsProxy' => 'Usa un proxy',
        'OptionsLang' => 'Lingua',
        'OptionsMain' => 'Principale',
        'OptionsPaths' => 'Percorsi',
        'OptionsInternet' => 'Internet',
        'OptionsConveniences' =>'Strumenti',
        'OptionsDisplay' => 'Visualizzazione',
        'OptionsToolbar' => 'Toolbar',
        'OptionsToolbars' => {0 => 'Nessuno', 1 => 'Piccolo', 2 => 'Grande'},
        'OptionsToolbarPosition' => 'Position',
        'OptionsToolbarPositions' => {0 => 'Top', 1 => 'Bottom', 2 => 'Left', 3 => 'Right'},
        'OptionsView' => 'Movies display',
        'OptionsViews' => {0 => 'Testo', 1 => 'Immagine', 2 => 'Dettagli'},
        'OptionsColumns' => 'Colonne',
        'OptionsMailer' => 'Metodo dei sendings',
        'OptionsSMTP' => 'Server',
        'OptionsFrom' => 'Mittente e-mail',
        'OptionsTransform' => 'Metti gli articoli alla fine dei titoli',
        'OptionsArticles' => 'Articoli (virgola separata)',
        'OptionsFormats' => 'tipo di supporto (virgola separata)',
        'OptionsSearchStop' => 'L\'utente può arrestare una ricerca',
        'OptionsAlwaysOriginal' => 'Use main title as the original one if none present',
        'OptionsHistory' => 'Dimensione della cronologia',
        'OptionsClearHistory' => 'Cancella cronologia',
		'OptionsStyle' => 'Skin',
        'OptionsDontAsk' => 'Don\'t ask anymore',

        'ImagesOptionsButton' => 'Settings',
        'ImagesOptionsTitle' => 'Settings for images list',
        'ImagesOptionsSelectColor' => 'Seleziona un colore',
        'ImagesOptionsBg' => 'Background',
        'ImagesOptionsBgPicture' => 'Usa un\'immagine di background',
        'ImagesOptionsFg'=> 'Selezione',
        'ImagesOptionsBgTooltip' => 'Cambia colore di background',
        'ImagesOptionsFgTooltip'=> 'Cambia il colore di selezione',
        'ImagesOptionsSizeLabel' => 'Size',
        'ImagesOptionsSizeList' => {0 => 'Very Small', 1 => 'Small', 2 => 'Medium', 3 => 'Large', 4 => 'Extra Large'},
        'ImagesOptionsSizeTooltip' => 'Select image size',
		        
        'DetailedOptionsTitle' => 'Settings for detailed list',
        'DetailedOptionsImageSize' => 'Images size',
        'DetailedOptionsGroupMovies' => 'Group movies by collection',
		'DetailedOptionsFields' => 'Scegli i campi da visualizzare',

        'ExtractButton' => 'Information',
        'ExtractTitle' => 'Video file information',
        'ExtractSize' => 'Size',
        'ExtractLength' => 'Runtime (minutes)',
        'ExtractType' => 'Video format',
        'ExtractAudioEncoding' => 'Audio format',
        'ExtractImport' => 'Use values',

        'ExportTitle' => 'Lista film dell\'esportazione',
        'ExportFilter' => 'Export only displayed movies',
        'ImportListTitle' => 'Importa un\'altra lista',
        'ImportExportFile' => 'Lista',
        'ImportExportSave' => 'Seleziona la lista',
        'ImportExportFieldsUnused' => 'Campi inutilizzati',
        'ImportExportFieldsUsed' => 'Campi usati',
        'ImportExportFieldsFill' => 'Tutti i campi',
        'ImportExportFieldsClear' => 'Nessun campo',
        'ImportExportFieldsEmpty' => 'Dovete scegliere almeno un campo',
        'ImportExportFileEmpty' => 'Devi specificare un nome per il file',
        'ExportFieldsTitle' => 'Campi da esportare',
        'ExportFieldsTip' => 'Campi prescelti che desideri esportare',
        'ImportFieldsTitle' => 'Campi da importare',
        'ImportFieldsTip' => 'Scegli i campi che vuoi importare',
        'ImportNewList' => 'Crea una nuova lista',
        'ImportCurrentList' => 'Aggiungi alla lista corrente',

        'FileOverwrite' => 'Questa lista già esiste. Desideri sovrascrivere?',

        'PanelSearchButton' => 'Fetch Information',
        'PanelSearchTip' => 'Cerca informazioni secondo il titolo del film inserito',
        'PanelSeenYes' => 'Movie already viewed',
        'PanelSeenNo' => 'Movie not viewed',
        'PanelLanguages' => 'Lingua',
        'PanelEncoding' => 'Encoding',
        'PanelImageTip' => 'Clicca sull\'immagine per sceglierne un\'altra. Right click for more options.',
        'PanelImageTitle' => 'Sceglie un\'immagine',
        'PanelTrailerTitle' => 'Select a file',
        'PanelInfoFrame' => 'Informazioni',
        'PanelAgeUnknown' => 'Sconosciuto',
        'PanelAgeNone' => 'Nessuno',
        'PanelAgeParent' => 'Parent Guidance',
        'PanelNobody' => 'Nessuno',
        'PanelUnknown' => 'Sconosciuto',
        'PanelLendedYes' => 'Lended',
        'PanelLendedNo' => 'Available',
        'PanelLendDateSelect' => 'Scegli una data',
        'PanelReturned' => 'Film restituito',
        'PanelRemove' =>'Elimina',
        'PanelClear' =>'Vider',
        'PanelReturnDate' => 'Data restituzione',
        'PanelWeb' => 'Leggi informazioni del film',
        'PanelWebTip' => 'Leggi informazioni su questo film disponibili sul web',
        'PanelRemoveTip' => 'Rimuovi il film corrente',
        'PanelMovieInfo' => 'Informazioni film',
        'PanelPrivateInfo' => 'Informazioni private',
        'PanelLendInfo' => 'Prestiti',

        'MenuNewList' => 'Nuova lista film',
        'MenuLend' => 'Visualizza films prestati',
        'MenuHistory' => 'Ultimi files aperti',
        'MenuExport' => 'Esporta',
        'MenuImport' => 'Importa',
        'MenuMovies' => 'Film',
        'MenuSearchMovies' => 'Cerca',
        'MenuSearchSelectedMovies' => 'Cerca nei film visualizzati',
        'MenuSearchAllMovies' => 'Cerca in tutti i films',
        'MenuViewAllMovies' => 'Vedi tutti i films',
        'MenuAllMovies' => 'Tutti',
        'MenuNotSeen' => 'Non visto',
        'MenuSeenOrNot' => 'Films visti o non visti',
        'MenuAllCategories' => 'Tutte le categorie',
        'MenuCategories' => 'Categoria film',
        'MenuRating' => 'Valutazione',
        'MenuAllRating' => 'Tutte le valutazioni',
        'MenuChooseRating' => 'Film che hanno una valutazione maggiore di...',
        'MenuBorrowing' => 'Disponibili o non films',
        'MenuBorrowed' => 'Films prestati',
        'MenuNotBorrowed' => 'Films disponibili',
        'MenuAge' => 'Films per un pubblico',
        'MenuAgeNone' => 'Tutte le età',
        'MenuAgeParent' => 'Richiede la presenza di un adulto',
        'MenuAgeLess' => 'Con un età di...',
		'MenuEdit'  => 'Modifica',
   	    'MenuDuplicate' => '_Duplicate movie',
		'MenuEditDeleteCurrent' => 'Cancella film corrente',
		'MenuEditLockMovies' => 'Blocca la lista',
        'MenuDisplay' => 'Visualizzazione',
        
        'MenuConfiguration' => 'Configurazione',
        'MenuDisplayOptions' => 'Informazioni da visulizzare',
        'MenuBorrowers' => 'Prestatari',
        'MenuRename' => 'Rinomina una categoria',
        'MenuGenresConversion' => 'Genre _Conversion',
        'MenuAbout' => 'Circa GCfilms',
        'MenuHelp' => '?',
        'MenuNewWindow' => 'Visulizza films in una nuova finestra',
        
        'ToolbarAll' => 'Visulizza tutto',
        'ToolbarAllTooltip' => 'Visulizza tutti i films',
        
        'RatingTitle' => 'Valutazione minima',
        'RatingLabel' => 'Following value is the minimum value a film rating should be to have this film displayed',

        'AgeTitle' => 'Età pubblico',
        'AgeLabel' => 'Solo i films adatti ad un pubblico con questa età saranno mostrati',

        'StatusMovies' => 'Film',
        
        'PluginsTitle' => 'Cerca un film',
        'PluginsFrame' => 'Cerca un sito',
        'PluginsLogo' => 'Logo',
        'PluginsName' => 'Name',
        'PluginsAuthor' => 'Author',
        'PluginsLang' => 'Language',
        'PluginsUseSite' => 'Use selected site for future searches',

        'BorrowersTitle' => 'Configurazione di chi prende in prestito',
        'BorrowersName' => 'Nome',
        'BorrowersEmail' => 'E-mail',
        'BorrowersAdd' => 'Aggiungi',
        'BorrowersRemove' => 'Elimina',
        'BorrowersEdit' => 'Modificare',
        'BorrowersTemplate' => 'Mail template',
        'BorrowersSubject' => 'Oggetto',
        'BorrowersNotice1' => '%1 sarà restituito con il nome di chi prende in prestito',
        'BorrowersNotice2' => '%2 sarà restituito con il titolo del film',
        'BorrowersNotice3' => '%3 sarà restituito con la data del prestito',

        'BorrowedTitle' => 'Film prestati',
        'BorrowedMovie' => 'Film',
        'BorrowedName' => 'Prestatario',
        'BorrowedDate' => 'Da',

        'MailTitle' => 'Manda un e-mail',
        'MailFrom' => 'Da: ',
        'MailTo' => 'A: ',
        'MailSubject' => 'Oggetto: ',
        'MailSmtpError' => 'Problema di connessione al server SMTP',
        'MailSendmailError' => 'Problema nell\'inviare l\'email',

        'SearchTooltip' => 'Cerca in tutti i films',
        'SearchTitle' => 'Cerca',
        'SearchMovieTitle' => 'Il titolo contiene',
        'SearchRating' => 'Valutazione maggiore o uguale',
        'SearchDirector' => 'Regista',
        'SearchActors' => 'Cast (separati dalla virgola)',
        'SearchType' => 'Genere',
        'SearchSeen' => 'Già visto',
        'SearchUndef' => 'Nessun problema',
        'SearchSeenYes' => 'Sì',
        'SearchSeenNo' => 'No',
        'SearchAge' => 'Età pubblico',
        'SearchYear' => 'Year betweeen',
        'SearchYearBetween' => 'and',
        
        'RenameTitle' => 'Rinomina una categoria',
        'RenameOld' => 'Nome corrente',
        'RenameNew' => 'Nuovo nome',
        
        'ImportWindowTitle' => 'Scegli i campi da importare',
        'ImportViewPicture' => 'Visualizza immagine',
        'ImportSelectAll' => 'Aggiungi tutti',
        'ImportSelectNone' => 'Rimuovi tutti',
        
        'ExportTarGzInfo' => 'L\'archivio è in questo file: ',
	
        'ExportHTMLWithJS' => 'Usa Javascript',
        'ExportHTMLFileTemplate' => 'Mascherina :',
        'ExportHTMLPreview' => 'Preview',
        'ExportHTMLNoPreview' => 'No preview available',
        'ExportHTMLTitle' => 'Titolo pagina',
        'ExportHTMLInfoFile' => 'La lista dei films è nel file: ',
        'ExportHTMLInfoDir' => 'Immagini sono in: ',
        'ExportHTMLHeightimg' => 'Altezza in pixel dell\'immagine da esportare : ',
        'ExportHTMLOpenFileInBrowser' => 'Open generated file in web browser',
        'ExportHTMLNote' => 'Lista generata con <a href="http://home.gna.org/gcfilms/">GCfilms</a>',
        'ExportHTMLInputTitle' => 'Immetti testo da cercare',
        'ExportHTMLSearchType1' => 'Solo il titolo',
        'ExportHTMLSearchType2' => 'Informazioni complete',
        'ExportHTMLSearchButton' => 'Cerca',
        'ExportHTMLSearchTitle' => 'Visualizza solo i films trovati con il criterio precedente',
        'ExportHTMLAllButton' => 'Tutto',
        'ExportHTMLAllTitle' => 'Visualizza tutti i films',
        'ExportHTMLExpand' => 'Estendi tutto',
        'ExportHTMLExpandTitle' => 'Visulizza tutte le informazioni dei films',
        'ExportHTMLCollapse' => 'Contrai tutto',
        'ExportHTMLCollapseTitle' => 'Contrai tutte le informazioni dei films',
        'ExportHTMLBorrowed' => 'Preso in prestito da: ',
        'ExportHTMLNotBorrowed' => 'Disponibile',
        'ExportHTMLTop' => 'Vertice',
	
        'ExportSQLWithPictures' => 'Copia le immagini in una sub directory',
        'ExportSQLWithDrop' => 'Includi DROP instruction',
        'ExportSQLWithCreate' => 'Includi CREATE instruction',
        'ExportSQLTableName' => 'Nome tabella',
        'ExportSQLInfoFile' => 'SQL file: ',

        'ExportXMLModelFile' => 'Template file',
        'ExportXMLModelText' => 'Template testo',
        'ExportXMLModels' => 'Template da usare',
        'ExportXMLUseFile' => 'Usa file',
        'ExportXMLUseModel' => 'Usa area di testo',

        'ExportCSVHeader' => 'Aggiungi colonna',
        'ExportCSVSeparator' => 'Delimitatore',
        'ExportCSVReplacement' => 'Ripeti delimitazione con',

        'ImportCSVHeader' => 'Ignora la prima linea',

        'ImportListName' => 'Titles list',
        'ImportListPlugin' => 'Site to be used',
        'ImportListUseFirst' => 'Select first one if many results',
        'ImportListCommentAuto' => 'Movie automatically imported.',
        'ImportListCommentSite' => 'Website: ',
        'ImportListCommentTitle' => 'Title: ',

        'ImportTellicoNotVideo' => 'File is not a Tellico video collection',

        'MultiSiteTitle' => 'Sito da usare per le ricerche',
        'MultiSiteUnused' => 'Plugins inutilizzati',
        'MultiSiteUsed' => 'Plugins da usare',
        'MultiSiteLang' => 'Riempi la lista con il plugins inglese',
        'MultiSiteEmptyError' => 'Hai una lista di siti vuota',
        'MultiSiteClear' => 'Pulisci la lista',
        
        'FieldsList' => {
            id => 'Informazione: Id',
            title => 'Informazione: Titolo',
            date => 'Informazione: Data',
            time => 'Informazione: Dureta',
            director => 'Informazione: Regista',
            nat => 'Informazione: Nazionalità',
            age => 'Informazione: Età minima',
            type => 'Informazione: Genere',
            image => 'Informazione: Immagine',
            orig => 'Informazione: Titolo originale',
            actors => 'Informazione: Cast',
            comment => 'Personale: Commento',
            synopsis => 'Informazione: Trama',
            seen => 'Personale: Già visto',
            number => 'Supporto: Numero',
            rating => 'Personale: Valutazione',
            format => 'Supporto: Tipo',
            url => 'Informazione: URL',
            place => 'Supporto: Luogo',
            video => 'Details: Video format',
            trailer => 'Détails : Video file',
            collection => 'Details: Collection',
            rank => 'Details: Rank',
            audio => 'Lingue: Audio',
            subt => 'Lingue: Sottotitoli',
            borrower => 'Prestiti: Nome',
            lendDate => 'Prestiti: Data',
            history => 'Prestiti: Cronologia',
        },        
        
        'DisplayOptionsTitle' => 'Oggetti da visualizzare',
        'DisplayOptionsAll' => 'Scegli tutto',
        'DisplayOptionsMain' => 'Oggetti principali',
        'DisplayOptionsActions' => 'Bottone azione',
        'DisplayOptionsSearch' => 'Bottone ricerche',

        'GenresTitle' => 'Genre Conversion',
        'GenresCategoryName' => 'Genre to use',
        'GenresCategoryMembers' => 'Genre to replace',
        'GenresLoad' => 'Load a list',
        'GenresExport' => 'Save list to a file',
        'GenresModify' => 'Edit conversion',
    );
}
1;
